==> v0.0.2.zip: lokinet/include/llarp/dht/search_job.hpp <==

#ifndef LLARP_DHT_SEARCH_JOB_HPP
#define LLARP_DHT_SEARCH_JOB_HPP
#include <llarp/dht.h>
#include <llarp/time.h>
#include <functional>
#include <llarp/dht/key.hpp>
#include <llarp/service/IntroSet.hpp>
#include <set>
#include <vector>

namespace llarp
{
  namespace dht
  {
    /// TODO: this should be made into a templated type
    struct SearchJob
    {
      const static uint64_t JobTimeout = 30000;

      typedef std::function< void(
          const std::vector< llarp::service::IntroSet >&) >
          IntroSetHookFunc;
      SearchJob();
      /// for routers
      SearchJob(const Key_t& requester, uint64_t requesterTX,
                const Key_t& target, const std::set< Key_t >& excludes,
                llarp_router_lookup_job* job);
      /// for introsets
      SearchJob(const Key_t& requester, uint64_t requesterTX,
                const Key_t& target, const std::set< Key_t >& excludes,
                IntroSetHookFunc found);
      // for introsets via tag
      SearchJob(const Key_t& requester, uint64_t requseterTX,
                IntroSetHookFunc found);

      void
      FoundRouter(const llarp_rc* router) const;

      void
      FoundIntros(
          const std::vector< llarp::service::IntroSet >& introset) const;

      void
      Timeout() const;

      bool
      IsExpired(llarp_time_t now) const;

      // only set if looking up router
      llarp_router_lookup_job* job = nullptr;
      IntroSetHookFunc foundIntroHook;
      llarp_time_t started;
      Key_t requester;
      uint64_t requesterTX;
      Key_t target;
      std::set< Key_t > exclude;
    };
  }  // namespace dht
}  // namespace llarp
#endif

==> v0.1.0.zip: lokinet/include/llarp/dht/search_job.hpp <==

#ifndef LLARP_DHT_SEARCH_JOB_HPP
#define LLARP_DHT_SEARCH_JOB_HPP
#include <llarp/dht.h>
#include <llarp/time.h>
#include <functional>
#include <llarp/dht/key.hpp>
#include <llarp/service/IntroSet.hpp>
#include <set>
#include <vector>

namespace llarp
{
  namespace dht
  {
    /// TODO: this should be made into a templated type
    struct SearchJob
    {
      const static uint64_t JobTimeout = 30000;

      typedef std::function< bool(
          const std::vector< llarp::service::IntroSet >&) >
          IntroSetHookFunc;

      typedef std::function< void(void) > DoneFunc;
      SearchJob();
      /// for routers
      SearchJob(const Key_t& requester, uint64_t requesterTX,
                const Key_t& target, const std::set< Key_t >& excludes,
                llarp_router_lookup_job* job);
      /// for introsets
      SearchJob(const Key_t& requester, uint64_t requesterTX,
                const Key_t& target, const std::set< Key_t >& excludes,
                IntroSetHookFunc found, DoneFunc done);
      // for introsets via tag
      SearchJob(const Key_t& requester, uint64_t requseterTX,
                IntroSetHookFunc found, DoneFunc done);

      void
      FoundRouter(const llarp_rc* router) const;

      bool
      FoundIntros(
          const std::vector< llarp::service::IntroSet >& introset) const;

      void
      Timeout() const;

      bool
      IsExpired(llarp_time_t now) const;

      // only set if looking up router
      llarp_router_lookup_job* job = nullptr;
      IntroSetHookFunc foundIntroHook;
      DoneFunc onDone;
      llarp_time_t started;
      Key_t requester;
      uint64_t requesterTX;
      Key_t target;
      std::set< Key_t > exclude;
    };
  }  // namespace dht
}  // namespace llarp
#endif
